@@ -11,14 +11,16 @@ import torch
 from torch.utils.model_zoo import load_url
 import numpy as np
 from .utils import from_rdkit_mol
+
+# TODO: Do we really want to define this at file level, rather than within some kind of class?
 MODEL_URL = """
-https://github.com/choderalab/espaloma_charge/releases/download/v0.0.0/model.pt
+https://github.com/choderalab/espaloma_charge/releases/download/v0.0.7/model.pt
 """
 
 def charge(
         molecule,
         total_charge: float = None,
-        model_url: str = MODEL_URL,
+        model_url: str = None,
     ) -> np.ndarray:
     """Assign machine-learned AM1-BCC partial charges to a molecule.
 
@@ -30,20 +32,25 @@ def charge(
     total_charge : float = 0.0
 
 
-    model_url : str
-        Model url.
+    model_url : str, optional, default=None
+        URL or filepath to retrieve the model from.
+        If None, the default MODEL_URL (defined at file level) is used
 
     Returns
     -------
     np.ndarray : (n_atoms, ) array of partial charges.
 
     """
-    with tempfile.TemporaryDirectory() as tempdir:
-        target_path = os.path.join(tempdir, "model.pt")
-        request.urlretrieve(model_url, target_path)
-        model = torch.load(target_path, map_location="cpu")
+    if model_url is None:
+        model_url = MODEL_URL
+
+    if not os.path.exists(".model.pt"):
+        request.urlretrieve(model_url, ".model.pt")
+
+    model = torch.load(".model.pt")
+
     if total_charge is None:
         total_charge = Chem.GetFormalCharge(molecule)
     graph = from_rdkit_mol(molecule)
-    graph = model(graph, total_charge=total_charge)
+    graph = model(graph)
     return graph.ndata["q"].cpu().detach().flatten().numpy()
